Model
---------

.. autofunction:: pai.model.container_serving_spec

.. autoclass:: pai.model.ResourceConfig

.. autoclass:: pai.model.Model
   :members:

.. autoclass:: pai.model.InferenceSpec
   :members:

.. autoclass:: pai.model.RegisteredModel
   :members:
